class puppet_enterprise::profile::console::workers(
  $database_password,
  $database_host     = $puppet_enterprise::database_host,
  $database_name     = $puppet_enterprise::dashboard_database_name,
  $database_port     = $puppet_enterprise::database_port,
  $database_user     = $puppet_enterprise::dashboard_database_user,
  $delayed_job_workers   = 2,
) inherits puppet_enterprise {

  include puppet_enterprise::packages
  realize Package['pe-puppet-dashboard']

  # Uses
  # $delayed_job_workers
  file { "${puppet_enterprise::params::defaults_dir}/pe-puppet-dashboard-workers":
    owner   => $puppet_enterprise::params::root_user,
    group   => $puppet_enterprise::params::root_group,
    mode    => '0644',
    content => template('puppet_enterprise/console/pe-puppet-dashboard-workers.default.erb'),
    notify  => Service['pe-puppet-dashboard-workers'],
  }

  class { 'puppet_enterprise::console::database':
      database_host     => $database_host,
      database_user     => $database_user,
      database_name     => $database_name,
      database_port     => $database_port,
      database_password => $database_password,
      migrate_db        => false,
  }

  # Work around for PE-6439
  # Declaring as a file resource so that other profiles will conflict and data
  # will not be overwritten if this profile is applied to a console node
  file {  '/etc/puppetlabs/puppet-dashboard/settings.yml':
    owner   => 'puppet-dashboard',
    group   => 'puppet-dashboard',
    mode    => '0640',
    content => inline_template('<%= {"daily_run_history_length" => 30}.to_yaml %>'),
  }

  class { 'puppet_enterprise::console::service':
      workers_only => true,
  }
}
